@@ -42,6 +42,7 @@ from sparknlp.annotator.stop_words_cleaner import *
 from sparknlp.annotator.coref import *
 from sparknlp.annotator.tf_ner_dl_graph_builder import *
 from sparknlp.annotator.cv import *
+from sparknlp.annotator.audio import *
 
 if sys.version_info[0] == 2:
     raise ImportError(
@@ -83,3 +84,4 @@ ws = sys.modules[__name__]
 er = sys.modules[__name__]
 coref = sys.modules[__name__]
 cv = sys.modules[__name__]
+audio = sys.modules[__name__]
