@@ -81,7 +81,7 @@ class LightPipeline:
                                     annotation.nChannels(),
                                     annotation.mode(),
                                     list(annotation.result()),
-                                    annotation.metadata())
+                                    dict(annotation.metadata()))
                 )
             else:
                 annotations.append(
@@ -89,8 +89,8 @@ class LightPipeline:
                                annotation.begin(),
                                annotation.end(),
                                annotation.result(),
-                               annotation.metadata(),
-                               annotation.embeddings)
+                               dict(annotation.metadata()),
+                               [])
                 )
         return annotations
 
@@ -103,7 +103,7 @@ class LightPipeline:
         ----------
         target : list or str
             The data to be annotated
-        optional_target: str
+        optional_target: list or str
             Optional data to be annotated (currently used for Question Answering)
 
         Returns
@@ -132,20 +132,27 @@ class LightPipeline:
 
         if optional_target == "":
             if type(target) is str:
-                target = [target]
+               target = [target]
+            elif type(target) is list and type(target[0]) is list:
+                raise TypeError("target is a 1D list")
+            else:
+                raise TypeError("target for annotation must be 'str' or list")
 
             for annotations_result in self._lightPipeline.fullAnnotateJava(target):
                 result.append(self.buildStages(annotations_result))
 
         else:
-            if type(target) is list or type(optional_target) is list:
-                raise TypeError("target and optional_target for annotation must be 'str'")
-
-            full_annotations = self._lightPipeline.fullAnnotateJava(target, optional_target)
-            stages = {}
-            for annotator_type, annotations in full_annotations.items():
-                stages[annotator_type] = self._annotation_from_java(annotations)
-            result.append(stages)
+            if type(target) is str and type(optional_target) is str:
+                annotations_dict = self._lightPipeline.fullAnnotateJava(target, optional_target)
+                result.append(self.buildStages(annotations_dict))
+            elif type(target) is list and type(optional_target) is list:
+                if type(target[0]) is list or type(optional_target[0]) is list:
+                    raise TypeError("target and optional_target is a 1D list")
+                full_annotations = self._lightPipeline.fullAnnotateJava(target, optional_target)
+                for annotations_dict in full_annotations:
+                    result.append(self.buildStages(annotations_dict))
+            else:
+                raise TypeError("target and optional_target for annotation must be both 'str' or both lists")
 
         return result
 
@@ -192,7 +199,7 @@ class LightPipeline:
         ----------
         target : list or str
             The data to be annotated
-        optional_target: str
+        optional_target: list or str
             Optional data to be annotated (currently used for Question Answering)
 
         Returns
@@ -210,22 +217,33 @@ class LightPipeline:
         >>> result["ner"]
         ['B-ORG', 'O', 'O', 'B-PER', 'O', 'O', 'B-LOC', 'O']
         """
+
         def reformat(annotations):
             return {k: list(v) for k, v in annotations.items()}
 
         if optional_target == "":
-            annotations = self._lightPipeline.annotateJava(target)
-        else:
-            if type(target) is list or  type(optional_target) is list:
-                raise TypeError("target and optional_target for annotation must be 'str'")
-            annotations = self._lightPipeline.annotateJava(target, optional_target)
+            if type(target) is str:
+                annotations = self._lightPipeline.annotateJava(target)
+                result = reformat(annotations)
+            elif type(target) is list:
+                if type(target[0]) is list:
+                    raise TypeError("target is a 1D list")
+                annotations = self._lightPipeline.annotateJava(target)
+                result = list(map(lambda a: reformat(a), list(annotations)))
+            else:
+                raise TypeError("target for annotation must be 'str' or list")
 
-        if type(target) is str:
-            result = reformat(annotations)
-        elif type(target) is list:
-            result = list(map(lambda a: reformat(a), list(annotations)))
         else:
-            raise TypeError("target for annotation may be 'str' or 'list'")
+            if type(target) is str and type(optional_target) is str:
+                annotations = self._lightPipeline.annotateJava(target, optional_target)
+                result = reformat(annotations)
+            elif type(target) is list and type(optional_target) is list:
+                if type(target[0]) is list or type(optional_target[0]) is list:
+                    raise TypeError("target and optional_target is a 1D list")
+                annotations = self._lightPipeline.annotateJava(target, optional_target)
+                result = list(map(lambda a: reformat(a), list(annotations)))
+            else:
+                raise TypeError("target and optional_target for annotation must be both 'str' or both lists")
 
         return result
 
@@ -269,4 +287,3 @@ class LightPipeline:
             Whether to ignore unsupported AnnotatorModels.
         """
         return self._lightPipeline.getIgnoreUnsupported()
-
